@@ -1,9 +1,12 @@
 detectCores <- local({
-  cache <- list()
+  cache <- list(NULL, NULL)
   
   function(logical = TRUE) {
+    key <- as.integer(logical) + 1L
+    value <- cache[[key]]
+    if (!is.null(value)) return(value)
+    
     stop_if_not(is.logical(logical), length(logical) == 1L, !is.na(logical))
-    key <- paste("logical=", logical, sep = "")
 
     ## Get number of system cores from option, cache, and finally
     ## detectCores().  This is also designed such that it is indeed
@@ -14,20 +17,20 @@ detectCores <- local({
       return(value)
     }
 
-    value <- cache[[key]]
-    if (is.null(value)) {
-      value <- parallel::detectCores(logical = logical)
+    value <- parallel::detectCores(logical = logical)
       
-      ## If unknown, set default to 1L
-      if (is.na(value)) value <- 1L
+    ## If unknown, set default to 1L
+    if (is.na(value)) {
+      value <- 1L
+    } else {
       value <- as.integer(value)
+    }
       
-      ## Assert positive integer
-      stop_if_not(length(value) == 1L, is.numeric(value),
+    ## Assert positive integer
+    stop_if_not(length(value) == 1L, is.numeric(value),
                 is.finite(value), value >= 1L)
 
-      cache[[key]] <<- value
-    }
+    cache[[key]] <<- value
     
     value
   }
